# lusid-python-tools
Python tools for the LUSID

![](https://github.com/finbourne/lusid-python-tools/workflows/commit-hook/badge.svg)
[![Build Status](https://travis-ci.org/finbourne/lusid-python-tools.svg?branch=master)](https://travis-ci.org/finbourne/lusid-python-tools)
